import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_cloudwatch
import aws_cdk.aws_ec2
import aws_cdk.aws_events
import aws_cdk.aws_iam
import aws_cdk.aws_logs
import aws_cdk.aws_s3
import aws_cdk.aws_s3_assets
import aws_cdk.aws_sqs
import aws_cdk.core
import aws_cdk.cx_api
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-lambda", "1.34.0", __name__[0:-6], "aws-lambda@1.34.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
